==> side_menu_v1.9.3.tar.gz: side_menu/l10n/de.js <==
OC.L10N.register("side_menu", {
    "Side menu": "Seitenmenü",
    "Enable the side menu": "Aktivieren Sie das Seitenmenü",
    "No": "Nein",
    "Yes": "Ja",
    "Menu": "Speisekarte",
    "Use the shortcut <span class=\"keyboard-key\">Ctrl<\/span>+<span class=\"keyboard-key\">o<\/span> to open and to hide the side menu. Use <span class=\"keyboard-key\">tab<\/span> to navigate.": "Verwenden Sie die Tastenkombination <span class=\"keyboard-key\">Strg<\/span>+<span class=\"keyboard-key\">o<\/span>, um das Seitenmenü zu öffnen und auszublenden. Verwenden Sie zum Navigieren die Registerkarte <span class=\"keyboard-key\">tab<\/span>.",
    "Top menu": "Hauptmenü",
    "Apps that not must be moved in the side menu": "Apps, die nicht im Seitenmenü verschoben werden müssen",
    "If there is no selection then the global configuration is applied.": "Wenn keine Auswahl vorhanden ist, wird die globale Konfiguration angewendet.",
    "Experimental": "Experimental",
    "Save": "Sparen",
    "You like this app and you want to support me?": "Du magst diese App und möchtest mich unterstützen?",
    "Buy me a coffe ☕": "Gib mir einen Kaffee ☕",
    "Hidden": "Versteckt",
    "Small": "Klein",
    "Normal": "Normal",
    "Big": "Groß",
    "Colors": "Farben",
    "Background color": "Hintergrundfarbe",
    "Background color of current app": "Hintergrundfarbe der aktuellen App",
    "Text color": "Textfarbe",
    "Loader": "Ladestandanzeige",
    "Icon": "Symbol",
    "Same color": "Selbe Farbe",
    "Opposite color": "Gegenfarbe",
    "Transparent": "Transparent",
    "Opaque": "Undurchsichtig",
    "Opener": "Öffner",
    "Default": "Standard",
    "Default (dark)": "Standard (dunkel)",
    "Hamburger": "Hamburger",
    "Hamburger (dark)": "Hamburger (dunkel)",
    "Hamburger 2": "Hamburger 2",
    "Hamburger 2 (dark)": "Hamburger 2 (dunkel)",
    "Before the logo": "Vor dem Logo",
    "After the logo": "Nach dem Logo",
    "Position": "Position",
    "Show only the opener (hidden logo)": "Nur den Öffner anzeigen (verstecktes Logo)",
    "Do not display the side menu and the opener if there is no application (eg: public pages).": "Zeigen Sie das Seitenmenü und den Öffner nicht an, wenn keine Anwendung vorhanden ist (z. B. öffentliche Seiten).",
    "Panel": "Panel",
    "Open the menu when the mouse is hover the opener (automatically disabled on touch screens)": "Öffnen Sie das Menü, wenn Sie die Maus über den Öffner bewegen (auf Touchscreens automatisch deaktiviert).",
    "Display the big menu": "Großes Menü anzeigen",
    "The big menu is not compatible with AppOrder.": "Le menu large n'est pas compatible avec l'application AppOrder",
    "Display the logo": "Logo anzeigen",
    "This feature is not compatible with the <code>big menu<\/code> display.": "Diese Funktion ist nicht mit der großen Menüanzeige kompatibel.",
    "Icons and texts": "Symbole und Texte",
    "Loader enabled": "Loader aktiviert",
    "Tips": "Tipps",
    "Always displayed": "Wird immer angezeigt",
    "The logo will be hidden when the menu is always displayed.": "Das Logo wird ausgeblendet, wenn das Menü immer angezeigt wird.",
    "This is the automatic behavior when the menu is always displayed.": "Dies ist das automatische Verhalten, wenn das Menü immer angezeigt wird.",
    "Not compatible with touch screens.": "Nicht kompatibel mit Touchscreens."
}, "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");

==> side_menu_v1.11.0.tar.gz: side_menu/l10n/de.js <==
OC.L10N.register("side_menu", {
    "Side menu": "Seitenmenü",
    "Enable the side menu": "Aktivieren Sie das Seitenmenü",
    "No": "Nein",
    "Yes": "Ja",
    "Menu": "Speisekarte",
    "Use the shortcut <span class=\"keyboard-key\">Ctrl<\/span>+<span class=\"keyboard-key\">o<\/span> to open and to hide the side menu. Use <span class=\"keyboard-key\">tab<\/span> to navigate.": "Verwenden Sie die Tastenkombination <span class=\"keyboard-key\">Strg<\/span>+<span class=\"keyboard-key\">o<\/span>, um das Seitenmenü zu öffnen und auszublenden. Verwenden Sie zum Navigieren die Registerkarte <span class=\"keyboard-key\">tab<\/span>.",
    "Top menu": "Hauptmenü",
    "Apps that not must be moved in the side menu": "Apps, die nicht im Seitenmenü verschoben werden müssen",
    "If there is no selection then the global configuration is applied.": "Wenn keine Auswahl vorhanden ist, wird die globale Konfiguration angewendet.",
    "Experimental": "Experimental",
    "Save": "Sparen",
    "You like this app and you want to support me?": "Du magst diese App und möchtest mich unterstützen?",
    "Buy me a coffe ☕": "Gib mir einen Kaffee ☕",
    "Hidden": "Versteckt",
    "Small": "Klein",
    "Normal": "Normal",
    "Big": "Groß",
    "Colors": "Farben",
    "Background color": "Hintergrundfarbe",
    "Background color of current app": "Hintergrundfarbe der aktuellen App",
    "Text color": "Textfarbe",
    "Loader": "Ladestandanzeige",
    "Icon": "Symbol",
    "Same color": "Selbe Farbe",
    "Opposite color": "Gegenfarbe",
    "Transparent": "Transparent",
    "Opaque": "Undurchsichtig",
    "Opener": "Öffner",
    "Default": "Standard",
    "Default (dark)": "Standard (dunkel)",
    "Hamburger": "Hamburger",
    "Hamburger (dark)": "Hamburger (dunkel)",
    "Hamburger 2": "Hamburger 2",
    "Hamburger 2 (dark)": "Hamburger 2 (dunkel)",
    "Before the logo": "Vor dem Logo",
    "After the logo": "Nach dem Logo",
    "Position": "Position",
    "Show only the opener (hidden logo)": "Nur den Öffner anzeigen (verstecktes Logo)",
    "Do not display the side menu and the opener if there is no application (eg: public pages).": "Zeigen Sie das Seitenmenü und den Öffner nicht an, wenn keine Anwendung vorhanden ist (z. B. öffentliche Seiten).",
    "Panel": "Panel",
    "Open the menu when the mouse is hover the opener (automatically disabled on touch screens)": "Öffnen Sie das Menü, wenn Sie die Maus über den Öffner bewegen (auf Touchscreens automatisch deaktiviert).",
    "Display the big menu": "Großes Menü anzeigen",
    "The big menu is not compatible with AppOrder.": "Das große Menü ist nicht mit AppOrder kompatibel.",
    "Display the logo": "Logo anzeigen",
    "This feature is not compatible with the <code>big menu<\/code> display.": "Diese Funktion ist nicht mit der großen Menüanzeige kompatibel.",
    "Icons and texts": "Symbole und Texte",
    "Loader enabled": "Loader aktiviert",
    "Tips": "Tipps",
    "Always displayed": "Wird immer angezeigt",
    "The logo will be hidden when the menu is always displayed.": "Das Logo wird ausgeblendet, wenn das Menü immer angezeigt wird.",
    "This is the automatic behavior when the menu is always displayed.": "Dies ist das automatische Verhalten, wenn das Menü immer angezeigt wird.",
    "Not compatible with touch screens.": "Nicht kompatibel mit Touchscreens.",
    "Big menu": "Große Speisekarte",
    "Live preview": "Live Vorschau",
    "Open apps in new tab": "Öffnen Sie Apps in einem neuen Tab",
    "Use the global setting": "Verwenden Sie die globale Einstellung"
}, "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
